/*
 * Copyright 2012 NGDATA nv
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ngdata.sep.demo;

import java.net.InetAddress;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ngdata.sep.EventListener;
import com.ngdata.sep.PayloadExtractor;
import com.ngdata.sep.SepEvent;
import com.ngdata.sep.SepModel;
import com.ngdata.sep.impl.BasePayloadExtractor;
import com.ngdata.sep.impl.SepConsumer;
import com.ngdata.sep.impl.SepModelImpl;
import com.ngdata.sep.util.zookeeper.ZkUtil;
import com.ngdata.sep.util.zookeeper.ZooKeeperItf;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hbase.Cell;
import org.apache.hadoop.hbase.CellUtil;
import org.apache.hadoop.hbase.HBaseConfiguration;
import org.apache.hadoop.hbase.util.Bytes;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * A simple consumer that just logs the events.
 */
public class LoggingConsumer {


    private static String localhost = "192.168.131.109";        //本机IP 不要用localhost
    private static String zookeeperHost = "master";             //zookeeper 服务器地址
    private static String subscriptionName = "logger";
    private static byte[] table = Bytes.toBytes("sep-user-demo");       //hbase 表
    private static byte[]  columnFamily = Bytes.toBytes("");        // 列族
    private static byte[]  columnQualifier = Bytes.toBytes("payload");  //列限定符

    private static String index = "medical_service_index";
    private static String type = "medical_service";


    public static void main(String[] args) throws Exception {
        Logger log = LoggerFactory.getLogger(LoggingConsumer.class);

        log.debug("进入 sep Events 开始");
        Configuration hbaseConf = HBaseConfiguration.create();
        hbaseConf.setBoolean("hbase.replication", true);

        ZooKeeperItf zk = ZkUtil.connect(zookeeperHost, 20000);
        SepModel sepModel = new SepModelImpl(zk, hbaseConf);
        if (!sepModel.hasSubscription(subscriptionName)) {
            sepModel.addSubscriptionSilent(subscriptionName);
        }

        PayloadExtractor payloadExtractor = new BasePayloadExtractor(table, columnFamily,columnQualifier);
        EventListener eventLogger = new EventLogger();
        SepConsumer sepConsumer = new SepConsumer(subscriptionName, 5000, eventLogger, 1, localhost, zk, hbaseConf,payloadExtractor);
        sepConsumer.start();

        System.out.println("Started");

        while (true) {
            Thread.sleep(Long.MAX_VALUE);
        }
    }

    private static class EventLogger implements EventListener {
        Logger log = LoggerFactory.getLogger(LoggingConsumer.class);

        @Override
        public void processEvents(List<SepEvent> sepEvents) {
            log.info("进入 sep Events 开始");
            for (SepEvent sepEvent : sepEvents) {
                log.debug("sep Events 处理 中");
                System.out.println("Received event:");
                System.out.println("  table = " + Bytes.toString(sepEvent.getTable()));
                System.out.println("  row = " + Bytes.toString(sepEvent.getRow()));
                log.debug("  table = " + Bytes.toString(sepEvent.getTable()));
                log.debug("  row = " + Bytes.toString(sepEvent.getRow()));
                Map<String, Object> json = new HashMap<String, Object>();
                for (Cell cell : sepEvent.getKeyValues()) {
                    String key = Bytes.toString(CellUtil.cloneQualifier(cell));
                    String value = Bytes.toString(CellUtil.cloneValue(cell));
                    log.debug("hbase  cloumn = " + key);
                    log.debug("hbase  value = " + value);
                    System.out.println("  key = " + key);
                    System.out.println("  value = " + value);


                    switch (key){
                        case "1":
                            break;
                        case "2":
                            break;
                        case "3":
                            break;
                    }
                    json.put(key, value);

                }
            }
            log.info("sep Events 处理 结束");
        }



    }
}
